	list p=16f628
;**************************************************************
;*  	Pinbelegung
;*	----------------------------------	
;*	PORTA: 	0 -
;*		1 -
;*		2 > Spannungsausgang
;*		3 -
;*		4 -
;*		5 -
;*		6 -
;*		7 -
;*
;*	PORTB:	0 > LED
;*		1 > LED
;*		2 > LED
;*		3 > LED
;*		4 > LED
;*		5 > LED
;*		6 > LED
;*		7 > LED
;*	
;**************************************************************
;
;sprut (zero) Bredendiek 01/2003
;
; Sgezahn mit der Referenzsspannungsquelle am Port RA2
; Spannung steigt in 4 Sekunden von 0V auf 3,125 V
;
; Prozessor 16F628 
;
; Prozessor-Takt 10 MHz
;
; LED-Zeile am PortB
;
;**************************************************************
; Includedatei fr den 16F628 einbinden

	#include <P16f628.INC>

	ERRORLEVEL      -302    	; SUPPRESS BANK SELECTION MESSAGES


; Configuration festlegen:
; Power on Timer, kein Watchdog, HS-Oscillator, kein Brown out, kein LV-programming
	__CONFIG	_MCLRE_ON & _PWRTE_ON & _WDT_OFF & _HS_OSC & _BODEN_OFF & _LVP_OFF

; Constanten festlegen
#define	LED	PORTB

; Variable festlegen
counter		equ	0x20		; Zhlstand fr Sgezahn
loops		equ	0x21		; ms-Zhler
loops2		equ	0x22		; Wait-Zhler


;**************************************************************
; Programmanfang

	org	0

;**************************************************************
; Initialisierung *********************************************

init
	BSF	STATUS,RP0		; Bank 1
	BSF	TRISA,2			; RA2 ist digital-input
	MOVLW	B'11100000'     	; enable VREF, RA2-output, VR=0000
	MOVWF	VRCON 			; low range mode
	clrf	OPTION_REG 
	clrf	TRISB			; PortB alle outputs 
	bcf     STATUS, RP0		; Bank 0
	clrf	PORTB			; LEDs aus
	clrf	INTCON        		; Interupt disable

	clrf	counter

;Hauptprogrammschleife
mainloop
	movfw	counter
	movwf	LED			; VR anzeigen

	movlw	B'11100000'
	iorwf	counter, w
	bsf	STATUS, RP0		; Bank 1
	movwf	VRCON 	
	bcf	STATUS, RP0		; Bank 0

	movlw	D'255'			; 250 ms Pause
	movwf	loops	
	call	WAIT		

	incf	counter, f
	movlw	B'00001111'
	andwf	counter, f		; VR auf 15 begrenzen

	goto	mainloop


;*****************************************************
;Zeitverzgerung um loops * 1 ms
; 10 MHz externer Takt bedeutet 2,5 MHz interner Takt
; also dauert 1 ms genau 2500 Befehle
; 250 Schleifen a 10 Befehle sind 2500 Befehle = 1 ms

WAIT
top     movlw   .250           ; timing adjustment variable (1ms)
        movwf   loops2
top2    nop                    ; sit and wait
        nop
        nop
        nop
	nop
        nop
        nop
        decfsz  loops2, F      ; inner loops complete?
        goto    top2           ; no, go again
                               ;
        decfsz  loops, F       ; outer loops complete?
        goto    top            ; no, go again
        retlw   0              ; yes, return from subWAIT


	end
